@@ -12,9 +12,9 @@ parser.add_argument("-ins", "--insert", help="Inserts the pages given at the tar
 parser.add_argument("-x", "--index", help="Page number at which pages should be inserted")     # Where to insert pages
 parser.add_argument("-rm", "--remove", nargs="+", type=int, help="Removes the pages given from the PDF specified")      # Flag to remove pages
 parser.add_argument("-g", "--get", nargs="+", type=int, help="Outputs the pages given from the PDF specified")      # Flag to get pages
-parser.add_argument("-i", "--input", default="./", help="Path to pages, defaults to current directory")      # Our input and output is the current directory by default
+parser.add_argument("-i", "--input", default="./", help="Path to pages, defaults to current directory. Can be a direct path to a file")      # Our input and output is the current directory by default
 parser.add_argument("-o", "--output", default="./", help="Path to where you want the papers saved, defaults to current directory")
-parser.add_argument("-aa", "--autoarticle", nargs="?", const="40", help="Creates a new article in .txt format at the output based on the PDF(s) and .txt-documents in the input of this length (sentances). Defaults to 40. Will save extracted text from PDF(s) as a .txt file")    # Const är vad det får om man ej anger det
+parser.add_argument("-aa", "--autoarticle", nargs="?", const="40", help="Creates a new article in .txt format at the output based on the PDF(s) and .txt-documents in the input of this length (sentances). Defaults to 40. Will save extracted text from PDF(s) as a .txt file in output directory")    # Const är vad det får om man ej anger det
 
 args = parser.parse_args()      # Collects our input in args
 
@@ -34,31 +34,48 @@ def create_page_list(path):
     Goes through each PDF file in the directory and adds every page of every file to the list.
     """
     pages = []
-    page_listings = os.listdir(path)    # A listing is a single PDF file
     pdf_readers = []
 
-    # Creates a PdfReader for each PDF document
-    for listing in page_listings:
+    if os.path.isdir(path):    # We need to check if this is a directory or a file
+        page_listings = os.listdir(path)    # A listing is a single PDF file in the directory
+         # Creates a PdfReader for each PDF document
+        for listing in page_listings:
+            try:
+                if not listing.endswith(".pdf"):    # We skip this listing if it's not an PDF
+                    print("Skipping \"" + listing + "\", not a PDF...")
+                    continue    # We continue the loop without creating PdfReader
+                pdf_readers.append(PdfReader(path + "/" + listing))
+            except Exception as e:  # Wow much error handeling...
+                print("Error: \"" + str(e) + "\" encountered, skipping \"" + listing + "\"...")     # Shitty error handling if we don't have a PDF
+                continue
+                # Goes through the document for each reader and adds all pages from that reader
+        for reader in pdf_readers:
+            n = 0
+            while True:
+                pages.append(reader.getPage(n))
+                try:
+                    reader.getPage(n + 1)   # Real shit programming to check if there is a next page
+                    n = n + 1
+                except:
+                    break
+        return pages
+    elif os.path.isfile(path):   # We have directly linked a PDF file
         try:
-            if not listing.endswith(".pdf"):    # We skip this listing if it's not an PDF
-                print("Skipping \"" + listing + "\", not a PDF...")
-                continue    # We continue the loop without creating PdfReader
-            pdf_readers.append(PdfReader(path + "/" + listing))
+            if not path.endswith(".pdf"):    # We skip this listing if it's not an PDF
+                print("Skipping \"" + path + "\", not a PDF...")
+            reader = PdfReader(path)
         except Exception as e:  # Wow much error handeling...
             print("Error: \"" + str(e) + "\" encountered, skipping \"" + listing + "\"...")     # Shitty error handling if we don't have a PDF
-            continue
-
-    # Goes through the document for each reader and adds all pages from that reader
-    for reader in pdf_readers:
         n = 0
         while True:
             pages.append(reader.getPage(n))
             try:
-                reader.getPage(n + 1)   # Real shit programming to check if there is a next page
+                reader.getPage(n + 1)
                 n = n + 1
-            except:
-                break
-    return pages
+            except: break
+        return pages
+    else:
+        print(str(path) + " could not be resolved as a path to file or directory")
 
 def create_print_version(pages_in):
     """Puts together the pages in pages_in to a single PDF in
@@ -146,7 +163,7 @@ def remove_pages(pages_in, page_numbers):
             print("Page " + str(n) + " could not be removed, skipping...")
             break
         else:
-            del pages_out[n - (1 + i)] 
+            del pages_out[index] 
             i-=-1
     PdfWriter(args.output + "/removed.pdf").addpages(pages_out).write()
 
@@ -179,16 +196,20 @@ def create_article(path, length):
     """ Creates a new article using Markov chains based on the PDF(s) and .txt(s)
     at path, and with length number of sentances
     """
-    pdf_listings = os.listdir(path)    # A listing is a single PDF file
     paths = []
 
-    for listing in pdf_listings:    # We need the full path to the PDF(s)
-        file_path = path + "/" + listing
-        paths.append(file_path)
+    if os.path.isdir(path):     # If we have a directory
+        pdf_listings = os.listdir(path)    # A listing is a single PDF file
 
-    if len(paths) == 0:
-        print("Cannot create article from empty directory")
-        return
+        for listing in pdf_listings:    # We need the full path to the PDF(s)
+            file_path = path + "/" + listing
+            paths.append(file_path)
+
+        if len(paths) == 0:
+            print("Cannot create article from empty directory")
+            return
+    elif os.path.isfile(path):
+        paths = path
 
     aa = Autoarticle(paths)     # Creates a new Autoarticle object
 
